# Copyright (C) 2021 Satoshi Konno. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http:#www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import netifaces


class Interface(object):
    @staticmethod
    def get_all_ipaddrs():
        ipaddrs = []
        for ifname in netifaces.interfaces():
            ifaddrs = netifaces.ifaddresses(ifname)
            if netifaces.AF_INET in ifaddrs.keys():
                inets = ifaddrs[netifaces.AF_INET]
                for inet in inets:
                    if 'addr' in inet.keys():
                        ipaddr = inet['addr']
                        if ipaddr == '127.0.0.1':
                            continue
                        ipaddrs.append(ipaddr)
        return ipaddrs
