# Copyright (C) 2021 Satoshi Konno. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http:#www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .transport.manager import Manager

from .node_profile import NodeProfile


class LocalNode(Manager):
    def __init__(self):
        super(LocalNode, self).__init__()

    def announce_message(self, msg):
        msg.DEOJ = NodeProfile.OBJECT
        return super(LocalNode, self).announce_message(msg)

    def send_message(self, msg, addr):
        msg.DEOJ = NodeProfile.OBJECT
        return super(LocalNode, self).send_message(msg, addr)
